# ================================================
# Replicating  Pan & Xu (2018) 
# ================================================

# ==== Load Required Packages ====
options(repos = c(CRAN = "https://cran.r-project.org"))

packages <- c("dplyr", "foreign", "GGally", "ggplot2",
 "knitr", "mvtnorm", "plyr", "psych")

for (pkg in packages) {
  if (!requireNamespace(pkg, quietly = TRUE)) {
    install.packages(pkg)
  }
  library(pkg, character.only = TRUE)
}

# ------------------------------------------------------------------------------
#                               DATA IMPORT & SETUP
# ------------------------------------------------------------------------------
paths <- list(
  sample10k   = "data/sample10K.RData",
  prov_corr   = "data/prov_corr.dta"
  cfa_search  = "output/result_cfa_search.RData",
  cfa_full    = "output/result_cfa.RData",
  cfa_ind     = "output/result_cfa_ind.RData",
  abs_boot    = "output/result_abs_boot.RData",
)

## keep Zuobiao 10 K survey as d10K, then bring in the full CFA file (d)
load(paths$sample10k)          # creates d
d10K <- d ; rm(d)

load(paths$cfa_full)           # creates d with lt1–lt3, PC1, provgb
load(paths$cfa_search)         # results.final
load(paths$cfa_ind)            # ses.*
load(paths$abs_boot)           # out.*
prov.corr <- read.dta(paths$prov_corr)

# ------------------------------------------------------------------------------
#                              Replication
# -----------------------------------------------------------------------------
##################################################################
## Figures 1: Ideology Dimensions
##################################################################
layout(matrix(1:3, nrow = 1), widths = c(1, 1, 1))
par(oma = c(1, 1, 2, 1), mar = c(1, 1, 1, 1))

plot_base <- function(data, overlay = NULL) {
  plot(1, type = "n", xlim = c(-2, 2), ylim = c(-2, 2),
       xlab = "", ylab = "", axes = FALSE)
  if (!is.null(overlay))
    lines(overlay$x, overlay$y, col = 4, lwd = 2, lty = overlay$lty)
  points(data, col = "gray30", pch = 1, cex = 1)
  arrows(-1.5, 0, 1.5, 0, code = 3, lwd = 3)
  arrows(0, -1.5, 0, 1.5, code = 3, lwd = 3)
  rect(-1.55, -1.55, 1.55, 1.55, border = NA, lty = 3)   # frame
  text(-1.3, 0.3, "Collectivism",              cex = 1.2)
  text( 1.3, 0.3, "Individualism",             cex = 1.2)
  text(0, -1.7, "Economic\nInterventionism",   cex = 1.2)
  text(0,  1.7, "Economic\nNon-intervention",  cex = 1.2)
}

## Subplot 1
set.seed(1234)
x1 <- matrix(rnorm(400, 0, 0.5), ncol = 2)
plot_base(x1)

## Subplot 2
x2 <- rmvnorm(200, sigma = matrix(c(1, 0.995, 0.995, 1) * 0.22, 2))
plot_base(x2, overlay = list(x = c(-1.5, 1.5), y = c(-1.5, 1.5), lty = 1))

## Subplot 3
theta <- seq(0, 2 * pi, length.out = 1000)
a <- 1.5; b <- 0.5; alpha <- 0.8
ex <- a * cos(theta) * cos(alpha) - b * sin(theta) * sin(alpha)
ey <- a * cos(theta) * sin(alpha) + b * sin(theta) * cos(alpha)
x3 <- rmvnorm(200, sigma = matrix(c(1, 0.75, 0.75, 1) * 0.22, 2))
plot_base(x3, overlay = list(x = ex, y = ey, lty = 3))

##################################################################
## Figures 4: PCA & EFA
##################################################################
# Figure 4(left)
## China's Ideological Spectrum — PCA only
questions <- paste0("q", 1:50)

pca.out <- prcomp(d10K[, questions], center = TRUE, scale. = TRUE)

d10K <- mutate(d10K,
               PC1 = -pca.out$x[, 1],
               PC2 =  pca.out$x[, 2],
               PC3 =  pca.out$x[, 3])

## 3. Derive objects used later
d$PC1 <- -pca.out$x[, 1]          # reverse sign to match paper
d$PC2 <-  pca.out$x[, 2]
d$PC3 <-  pca.out$x[, 3]
ord   <- order(d$PC1)

RMatrix        <- pca.out$rotation
RMatrix[, 1]   <- -RMatrix[, 1]
for (i in 1:50) RMatrix[, i] <- RMatrix[, i] * sd(pca.out$x[, i])

## 4. Figure 4 (left) – scree plot of PCA vs EFA
tmp <- pdf(NULL)                      # open a null device (nothing is shown)
out <- psych::scree(d[, questions])   # still computes pcv and fv
fv  <- out$fv                         # factor eigen-values
pcv <- out$pcv                        # component eigen-values

# run summary(pca.out) to see the complete PCA results

par(mar = c(5, 4, 1, 1))
plot(1, type = "n", ylim = c(-0.5, 10), xlim = c(1, 50),
     xlab = "", ylab = "", axes = FALSE)
# Reduced text size from 1.5 to 1.2
mtext("i'th Principal Component or Factor", 1, 2.5, cex = 1.0)
mtext("Eigen-Values of Components and Factors", 2, 2.5, cex = 1.0)
abline(h = 1,               col = "#AAAAAA50", lwd = 4)
abline(h = seq(-1, 20, .5), col = "#AAAAAA50")
abline(v = seq(0, 50, 2),   col = "#AAAAAA50")
lines(fv, col = "gray30", lwd = 2, lty = 3)
points(fv,  pch = 16, col = "white", cex = 1.8)
lines(pcv, col = 1,       lwd = 2)
points(pcv, pch = 16, col = "white", cex = 1.8)
points(fv,  pch = 1, col = "gray30", cex = 1.1)
points(pcv, pch = 16, col = 1,       cex = 1.2)
axis(1, at = seq(0, 50, 10), cex.axis = 1.1)  
axis(2, at = 0:10,          cex.axis = 1.1)  
legend("topright",
       c("Principal Component", "Factor"),
       pch = c(16, 1), col = c(1, "gray30"),
       bty = "n", cex = 1.2)  # Reduced from 1.4
box()

# Figure 4(right)
choice  <- ifelse(d[, questions] >= 2.5, 1, 0)
s       <- scale(d[, questions])
R       <- pca.out$rotation
W       <- solve(R)
x       <- pca.out$x
s.mean  <- attr(s, "scaled:center")
s.sd    <- attr(s, "scaled:scale")

pred_fun <- function(i, accum = TRUE) {
  if (i == 0) {
    pred <- matrix(0, nrow(s), ncol(s))
  } else if (accum) {
    pred <- x[, 1:i, drop = FALSE] %*% W[1:i, , drop = FALSE]
  } else {
    pred <- x[,  i , drop = FALSE] %*% W[ i , , drop = FALSE]
  }
  sweep(pred, 2, s.sd, `*`) +
    matrix(s.mean, nrow(pred), 50, byrow = TRUE)
}

res1  <- sapply(0:50, function(i) mean(choice == (pred_fun(i)        >= 2.5), na.rm = TRUE))
res2  <- sapply(0:50, function(i) if (i == 0) mean(choice == 0, na.rm = TRUE)
                               else mean(choice == (pred_fun(i, FALSE) >= 2.5), na.rm = TRUE))
power <- (res2[-1] - res2[1]) * 100

ylim.power <- range(power, 0) + c(-1, 1)
lab.top <- c(0, 1, 3, 5, 10, 20, 30, 40, 50)
lab.bot <- c(1, 3, 5, 10, 20, 30, 40, 50)

par(mfrow = c(2, 1), mar = c(4.5, 5, 1, 1))

## (top) accumulative PCP
plot(0:50, res1 * 100, type = "n",
     xlab = "", ylab = "Percentage Correctly Predicted\n(Accumulative PCP) %",
     xlim = c(0, 50), ylim = c(58, 103), axes = FALSE)
abline(h = seq(60, 100, 5), v = c(1, 3, seq(0, 50, 2)), col = "#AAAAAA50")
lines(0:50, res1 * 100, lwd = 2)
points(0:50, res1 * 100, pch = 16, col = "white", cex = 1.8)
points(0:50, res1 * 100, pch = 16, cex = 1.2)
text(lab.top, res1[lab.top + 1] * 100, labels = round(res1[lab.top + 1] * 100, 1),
     pos = 3, cex = 0.8)
mtext("Number of Principal Components", 1, 2.5)
axis(1, at = c(1:3, seq(0, 50, 10))); axis(2); box()

## (bottom) independent predictive power
plot(1:50, power, type = "n",
     xlab = "", ylab = "Independent Predictive Power\n(Increase in PCP %)",
     xlim = c(0, 51), ylim = ylim.power, axes = FALSE)
abline(h = seq(floor(ylim.power[1]), ceiling(ylim.power[2]), 2),
       v = c(1, 3, seq(0, 50, 2)), col = "#AAAAAA50")
lines(1:50, power, lwd = 2)
points(1:50, power, pch = 16, col = "white", cex = 1.8)
points(1:50, power, pch = 16, cex = 1.2)
text(lab.bot, power[lab.bot], labels = round(power[lab.bot], 1),
     pos = 3, cex = 0.8)
abline(h = 0, col = "gray", lwd = 2)
mtext("i-th Principal Component", 1, 2.5)
axis(1, at = c(1:3, seq(0, 50, 10))); axis(2); box()

##################################################################
## Table 1: CFA Model Selection
##################################################################
post.cov     <- which(results.final$post.check == 1)
good.results <- results.final[post.cov, ]
best.row     <- good.results[which.min(good.results$chisq), ]

## best model for each dimensionality (3 → 1)
best.by.ndim <- good.results %>%
  group_by(ndim) %>%
  slice_min(chisq, n = 1, with_ties = FALSE) %>%
  ungroup() %>%
  arrange(desc(ndim)) %>%
  mutate(Model = c("Model A", "Model B", "Model C"))

## Δχ²  and p-value versus the best (Model A)
best.chisq <- best.by.ndim$chisq[1]
best.ndim  <- best.by.ndim$ndim[1]

tbl <- best.by.ndim %>%
  mutate(`No. of Dimensions` = ndim,
         χ2   = chisq,
         CFI  = cfi,
         TLI  = tli,
         RMSEA = rmsea,
         `Δχ2`   = chisq - best.chisq,
         df     = best.ndim - ndim,
         `p-Value` = ifelse(df > 0,
                            1 - pchisq(`Δχ2`, df),
                            NA_real_)) %>%
  select(Model, `No. of Dimensions`, χ2, CFI, TLI, RMSEA, `Δχ2`, `p-Value`) %>%
  
  ## cosmetic formatting
mutate(across(c(CFI, TLI, RMSEA),
              ~ sub("^0", ".", sprintf("%.3f", .x))),
       across(c(χ2, `Δχ2`),
              ~ formatC(.x, format = "d", big.mark = ",")),
       `p-Value` = ifelse(is.na(`p-Value`), "",
                          sprintf("%.3f", `p-Value`)))

knitr::kable(
  tbl,
  booktabs = TRUE,
  align = c("l", "c", rep("c", 6))
)

##################################################################
## Figures 5: χ² and RMSEA
##################################################################
par(mfrow = c(1, 2), mar = c(4, 4, 1, 1))

plot(jitter(results.final$ndim[-post.cov]), results.final$chisq[-post.cov],
     xlim = c(0.5, 7.5), ylim = c(64500, 68100),
     col = "gray80", xlab = "# Latent Factors", ylab = "Chi-square")
points(jitter(results.final$ndim[setdiff(post.cov, best.row$id)]),
       results.final$chisq[setdiff(post.cov, best.row$id)],
       pch = 1, col = "gray30")
points(best.row$ndim, best.row$chisq, pch = 16, cex = 1.5)

plot(jitter(results.final$ndim[-post.cov]), results.final$rmsea[-post.cov],
     xlim = c(0.5, 7.5), ylim = c(0.0738, 0.0756),
     col = "gray80", xlab = "# Latent Factors", ylab = "RMSEA")
points(jitter(results.final$ndim[setdiff(post.cov, best.row$id)]),
       results.final$rmsea[setdiff(post.cov, best.row$id)],
       pch = 1, col = "gray30")
points(best.row$ndim, best.row$rmsea, pch = 16, cex = 1.5)

##################################################################
## Figure 9: Correlations among Latent Traits and PC1
##################################################################

## variables of interest and basic cleaning
vars      <- c("lt1", "lt2", "lt3", "PC1")
d_clean   <- na.omit(d[, vars])          # drop rows with any NA
d_clean[] <- lapply(d_clean, as.numeric) # ensure numeric columns

## pair plot with adjustments to prevent overlap
p <- ggpairs(
        d_clean,
        columnLabels = c("Political Liberalism",
                         "Promarket /\nNon-traditional Values",
                         "Nationalism (× -1)",
                         "1st Principal\nComponent"),  # Added line break
        lower = list(continuous = wrap("points", alpha = 0.3, size = 0.2),
                     combo      = wrap("dot",    alpha = 0.4, size = 0.2)),
        upper = list(continuous = wrap("cor", 
                                      size  = 5,
                                      colour = "black",
                                      fontface = "bold")),
        switch = "both"  # Moves y-axis labels to left side
     ) +
     theme(
       axis.text.x = element_text(size = 8, colour = "black", angle = 45, hjust = 1),  # Angled x-axis labels
       axis.text.y = element_text(size = 8, colour = "black"),
       axis.title = element_text(size = 10, face = "bold"),
       strip.text = element_text(size = 10, face = "bold", margin = margin(0,0,5,0)),  # Adjusted panel label spacing
       panel.spacing = unit(0.5, "lines")  # Added space between panels
     )

# Add more space at bottom for x-axis labels
p <- p + theme(plot.margin = margin(10, 10, 20, 10))

# Display the plot
p

##################################################################
## Figure 10: Education and Income
##################################################################
## plotting settings
colsU  <- c(1, "gray50", "gray80")          # upper series (3 traits)
pchU   <- c(16, 17, 15)
offU   <- seq(-0.15, 0.15, length.out = 3)

colsL  <- c(1, "gray50")                    # lower series (2 traits)
pchL   <- c(16, 17)
offL   <- c(-0.10, 0.10)

layout(matrix(c(1, 2, 3, 4), 2, 2, byrow = TRUE))
par(oma = c(4, 4, 4, 2), mar = c(4.5, 4.5, 2, 2))

##################################################################
## Figures 12: Accounts by Level and Category 
##################################################################
## 1 Education – Zuobiao (upper-left)
output <- ses.edu
plot(1, type = "n", xlim = c(0.5, 3.5), ylim = c(-0.6, 0.6),
     xlab = "Education", ylab = "", xaxt = "n",
     cex.lab = 1.5, cex.axis = 1.5)
axis(1, at = 1:3, labels = c("Below\nCollege", "College\n", "Above\nCollege"),
     tick = FALSE, line = 1, cex.axis = 1.2)
abline(h = 0); grid(col = "#AAAAAA50", lwd = 1)
for (k in 1:3) {
  for (i in 1:nrow(output))
    lines(rep(i, 2) + offU[k], output[i, k, 3:4], lwd = 4, col = colsU[k])
  points((1:nrow(output)) + offU[k], output[, k, 1],
         pch = pchU[k], cex = 2, col = colsU[k])
}
legend("topleft",
       legend = c("Political Liberalism",
                  "Promarket/Nontraditional Values",
                  "Nationalism × (–1)"),
       col = colsU, pch = pchU, lty = 1, lwd = 3, bty = "n", cex = 1.1,
       y.intersp = 1.2)

## 2 Income – Zuobiao (upper-right) 
output <- ses.income
plot(1, type = "n", xlim = c(0.5, 4.5), ylim = c(-0.6, 0.6),
     xlab = "Annual Income", ylab = "", xaxt = "n",
     cex.lab = 1.5, cex.axis = 1.5)
axis(1, at = 1:4, labels = c("0–50K", "50–150K", "150–300K", ">300K"),
     tick = FALSE, cex.axis = 1.2)
abline(h = 0); grid(col = "#AAAAAA50", lwd = 1)
for (k in 1:3) {
  for (i in 1:nrow(output))
    lines(rep(i, 2) + offU[k], output[i, k, 3:4], lwd = 4, col = colsU[k])
  points((1:nrow(output)) + offU[k], output[, k, 1],
         pch = pchU[k], cex = 2, col = colsU[k])
}

# Add Zuobiao label above first row
mtext("A  Zuobiao Sample", side = 3, outer = TRUE, line = 1, adj = 0.5, cex = 1.2)

## 3  Education – ABS (lower-left)
output <- out.edu
plot(1, type = "n", xlim = c(0.5, 5.5), ylim = c(-1, 1),
     xlab = "", ylab = "", xaxt = "n",
     cex.lab = 1.5, cex.axis = 1.5)
axis(1, at = c(1, 3, 5),
     labels = c("< Primary\nSchool", "Middle School", "College or Above"),
     tick = FALSE, cex.axis = 1.1)
axis(1, at = c(2, 4), labels = c("Primary School", "High School"),
     tick = FALSE, line = 1.5, cex.axis = 1.1)
abline(h = 0); grid(col = "#AAAAAA80", lwd = 1)
for (k in 1:2) {
  for (i in 1:nrow(output))
    lines(rep(i, 2) + offL[k], output[i, k, 2:3], lwd = 4, col = colsL[k])
  points((1:nrow(output)) + offL[k], output[, k, 1],
         pch = pchL[k], cex = 2, col = colsL[k])
}
legend("topleft",
       legend = c("Political Liberalism", "Nontraditional Values"),
       col = colsL, pch = pchL, lty = 1, lwd = 3, bty = "n", cex = 1.1,
       y.intersp = 1.2)
box()

## 4  Income – ABS (lower-right) 
output <- out.inc
plot(1, type = "n", xlim = c(0.5, 5.5), ylim = c(-1, 1),
     xlab = "Self-Reported Income Level", ylab = "", xaxt = "n",
     cex.lab = 1.5, cex.axis = 1.5)
axis(1, at = 1:5,
     labels = c("Lowest", "Low", "Middle", "High", "Highest"),
     tick = FALSE, cex.axis = 1.2)
abline(h = 0); grid(col = "#AAAAAA80", lwd = 1)
for (k in 1:2) {
  for (i in 1:nrow(output))
    lines(rep(i, 2) + offL[k], output[i, k, 2:3], lwd = 4, col = colsL[k])
  points((1:nrow(output)) + offL[k], output[, k, 1],
         pch = pchL[k], cex = 2, col = colsL[k])
}
box()

# Add ABS label below second row
mtext("B  ABS Sample", side = 1, outer = TRUE, line = 2, adj = 0.5, cex = 1.2)

##################################################################
## Figures 11: Ideological Measures and Age 
##################################################################
## settings
pchA <- c(16, 17, 15)      # Zuobiao panels
pchB <- 16                 # ABS panels
leg  <- c("Political Liberalism",
          "Promarket/Nontraditional Values",
          "Nationalism × (–1)")
layout(matrix(c(1, 2, 3, 4, 5, 0), 2, 3, byrow = TRUE))
par(oma = c(4, 4, 2, 2), mar = c(4.5, 4.5, 2, 2))

## Top row – Zuobiao (3 traits) 
outZ <- ses.age
for (k in 1:3) {
  plot(1, type = "n", xlim = c(-1, 45), ylim = c(-0.6, 0.6),
       xlab = "Age", ylab = "", xaxt = "n",
       cex.lab = 1.5, cex.axis = 1.5)
  axis(1, at = seq(1, 43, 3), labels = seq(18, 60, 3), cex.axis = 1.2)
  abline(h = 0); grid(col = "#AAAAAA50", lwd = 1)
  for (i in 1:nrow(outZ))
    lines(rep(i, 2), outZ[i, k, 3:4], lwd = 2)  # Thinner lines (was 4)
  points(1:nrow(outZ), outZ[, k, 1], pch = pchA[k], cex = 1.5)  # Smaller dots (was 2)
  title(leg[k], line = -2, cex.main = 1.5)
}

## Bottom row – ABS (2 traits) 
outA <- out.age
for (k in 1:2) {
  plot(1, type = "n", xlim = c(0.5, 43.5), ylim = c(-1, 1.5),
       xlab = "Age", ylab = "", xaxt = "n",
       cex.lab = 1.5, cex.axis = 1.5)
  axis(1, at = seq(1, 43, 3), labels = seq(18, 60, 3), cex.axis = 1.2)
  abline(h = 0); grid(col = "#AAAAAA50", lwd = 1)
  for (i in 1:nrow(outA))
    lines(rep(i, 2), outA[i, k, 2:3], lwd = 2)  # Thinner lines (was 4)
  points(1:nrow(outA), outA[, k, 1], pch = pchB, cex = 1.5)  # Smaller dots (was 2)
  title(c("Political Liberalism", "Nontraditional Values")[k],
        line = -2, cex.main = 1.5)
}

## row labels
mtext("A  Zuobiao Sample", side = 3, outer = TRUE, line = 0, adj = 0.5, cex = 1.2)
mtext("B  ABS Sample", side = 1, outer = TRUE, line = 1, adj = 0.5, cex = 1.2)

##################################################################
## Figures A5: Age-based Divergence in Rural Areas
##################################################################
mycol = c(1, "gray50")
mypch = c(16, 17)
offset <- c(-0.1,0.1)

# Set up 2x2 layout with smaller margins
par(mfrow=c(2,2), mar=c(4.5,4.5,3,2), oma=c(0,0,2,0))

# 1. Urban Political Liberalism
output <- out.age.urban
plot(1, type="n", ylab="Estimate", 
     xlab="Age", ylim=c(-1,1.5), xlim=c(0.5,43.5),
     cex.lab=1.3, cex.axis=1.3, xaxt="n", main="Urban: Political Liberalism")
abline(h=0)
axis(1, at=seq(1,43,by=3), lab=seq(18,60,by=3), cex.axis=1.3)
grid(col="#AAAAAA50", lwd=1)
n <- dim(output)[1]
for (k in 1) {
    for (i in 1:n) {
        lines(c(i,i) + offset[k], c(output[i,k,2],output[i,k,3]), lwd=3, col=1)
    }
    points(c(1:n) + offset[k], output[,k,1], pch=mypch[k], cex=1.5, col=1)
}
box()

# 2. Urban Non-Traditional Values
plot(1, type="n", ylab="Estimate",
     xlab="Age", ylim=c(-1,1.5), xlim=c(0.5,43.5),
     cex.lab=1.3, cex.axis=1.3, xaxt="n", main="Urban: Non-Traditional Values")
abline(h=0)
axis(1, at=seq(1,43,by=3), lab=seq(18,60,by=3), cex.axis=1.3)
grid(col="#AAAAAA50", lwd=1)
for (k in 2) {
    for (i in 1:n) {
        lines(c(i,i) + offset[k], c(output[i,k,2],output[i,k,3]), lwd=3, col=1)
    }
    points(c(1:n) + offset[k], output[,k,1], pch=mypch[k], cex=1.5, col=1)
}
box()

# 3. Rural Political Liberalism
output <- out.age.rural
plot(1, type="n", ylab="Estimate",
     xlab="Age", ylim=c(-1,1.5), xlim=c(0.5,43.5),
     cex.lab=1.3, cex.axis=1.3, xaxt="n", main="Rural: Political Liberalism")
abline(h=0)
axis(1, at=seq(1,43,by=3), lab=seq(18,60,by=3), cex.axis=1.3)
grid(col="#AAAAAA50", lwd=1)
n <- dim(output)[1]
for (k in 1) {
    for (i in 1:n) {
        lines(c(i,i) + offset[k], c(output[i,k,2],output[i,k,3]), lwd=3, col=1)
    }
    points(c(1:n) + offset[k], output[,k,1], pch=mypch[k], cex=1.5, col=1)
}
box()

# 4. Rural Non-Traditional Values
plot(1, type="n", ylab="Estimate",
     xlab="Age", ylim=c(-1,1.5), xlim=c(0.5,43.5),
     cex.lab=1.3, cex.axis=1.3, xaxt="n", main="Rural: Non-Traditional Values")
abline(h=0)
axis(1, at=seq(1,43,by=3), lab=seq(18,60,by=3), cex.axis=1.3)
grid(col="#AAAAAA50", lwd=1)
for (k in 2) {
    for (i in 1:n) {
        lines(c(i,i) + offset[k], c(output[i,k,2],output[i,k,3]), lwd=3, col=1)
    }
    points(c(1:n) + offset[k], output[,k,1], pch=mypch[k], cex=1.5, col=1)
}
box()

# Add overall title
mtext("Age Trends in Political and Cultural Values by Urban/Rural Residence", 
      outer=TRUE, cex=1.5, line=0)



##################################################################
## Figures 12: Correlates of Provincial Ideological Measure
##################################################################
lt.prov <- ddply(d, .(provgb), function(x){
    data.frame(lt1 = mean(x$lt1),
               lt2 = mean(x$lt2),
               lt3 = mean(x$lt3))
})

prov <- join(prov.corr, lt.prov, by='provgb', type='left', match='all')
prov <- subset(prov, !provgb %in% c(54, 63, 64))

# Set up 1x3 layout
par(mfrow=c(1,3), mar=c(4.5,4.5,2,1), oma=c(0,0,2,0))

## 1. Income plot
plot(1, type="n", ylim=c(-0.4,0.4), xlim=c(9.75,10.75),
     xlab="Log Income per capita", ylab="Political Liberalism",
     cex.lab=1.3, cex.axis=1.3)
grid(col="#AAAAAA50", lwd=1.5)
points(log(prov$income), prov$lt1, pch=16, cex=2, col="gray80")
lines(lowess(log(prov$income), prov$lt1, f=1), col=1, lwd=3)

## 2. Trade plot
plot(1, type="n", ylim=c(-0.4,0.4), xlim=c(-5,155),
     xlab="Trade openness", ylab="",
     cex.lab=1.3, cex.axis=1.3)
grid(col="#AAAAAA50", lwd=1.5)
points(prov$openness, prov$lt1, pch=16, cex=2, col="gray80")
lines(lowess(prov$openness, prov$lt1, f=1), col=1, lwd=3)
text(145,0.10,"Beijing",cex=1.1)
text(135,0.17,"Shanghai",cex=1.1)
text(115,0.21,"Guangdong",cex=1.1)

## 3. Urbanization plot
plot(1, type="n", ylim=c(-0.4,0.4), xlim=c(25,92),
     xlab="Urbanization (%)", ylab="",
     cex.lab=1.3, cex.axis=1.3)
grid(col="#AAAAAA50", lwd=1.5)
points(prov$urban, prov$lt1, pch=16, cex=2, col="gray80")
lines(lowess(prov$urban, prov$lt1, f=1), col=1, lwd=3)

# Add overall title
mtext("Provincial Correlates of Political Liberalism", outer=TRUE, cex=1.5)
